==> ieg_validators-0.1.2-py3-none-any.whl: ieg_validators/cloudport/models/blip/settings.py <==
from typing import List
from pydantic import BaseModel


class IceServerItem(BaseModel):
    url: str
    username: str
    credential: str


class Webrtc(BaseModel):
    iceTransportPolicy: str
    iceServer: List[IceServerItem]


class MissingListBucket(BaseModel):
    consider_future_playlists: bool


class Help(BaseModel):
    cloudport_help: str


class ExtractTcIn(BaseModel):
    __root__: dict[str, bool]


class CustomerTemplate(BaseModel):
    default_template: str
    xmorph: str


class MxfChannelLayout(BaseModel):
    __root__: dict[str, list[int]]


class DbCleanup(BaseModel):
    days_for_headend_event: int
    days_for_playlist_item: int
    max_rows_to_delete_at_once: int
    sleep_duration: float
    playlist_types_to_remove: List[str]


class SendPlaylistErrorToItem(BaseModel):
    channel_code: List[str]
    to: str
    cc: str


class PlaylistAlerts(BaseModel):
    send_dynamic_image_missing_list_to: str
    hourly_drift_report: str


class Epub(BaseModel):
    server: str
    enabled: bool
    auto_subscribe: bool
    auto_pull_on_live_off: bool
    extra_duration_for_playing_event: int
    break_exit_mode: str


class Playout(BaseModel):
    window_start_hours: int
    window_end_hours: int


class Contact(BaseModel):
    phone: str
    email: str


class Defaults(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class Development(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class Test(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class Production(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class Staging(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class AutomationSettings(BaseModel):
    defaults: Defaults
    development: Development
    test: Test
    production: Production
    staging: Staging

==> ieg_validators-0.1.6-py3-none-any.whl: ieg_validators/cloudport/models/blip/settings.py <==
from typing import List
from pydantic import BaseModel


class IceServerItem(BaseModel):
    url: str
    username: str
    credential: str


class Webrtc(BaseModel):
    iceTransportPolicy: str
    iceServer: List[IceServerItem]


class MissingListBucket(BaseModel):
    consider_future_playlists: bool


class Help(BaseModel):
    cloudport_help: str


class ExtractTcIn(BaseModel):
    __root__: dict[str, bool]


class CustomerTemplate(BaseModel):
    default_template: str
    xmorph: str


class MxfChannelLayout(BaseModel):
    __root__: dict[str, list[int]]


class DbCleanup(BaseModel):
    days_for_headend_event: int
    days_for_playlist_item: int
    max_rows_to_delete_at_once: int
    sleep_duration: float
    playlist_types_to_remove: List[str]


class SendPlaylistErrorToItem(BaseModel):
    channel_code: List[str]
    to: str
    cc: str


class PlaylistAlerts(BaseModel):
    send_dynamic_image_missing_list_to: str
    hourly_drift_report: str


class Epub(BaseModel):
    server: str
    enabled: bool
    auto_subscribe: bool
    auto_pull_on_live_off: bool
    extra_duration_for_playing_event: int
    break_exit_mode: str


class Playout(BaseModel):
    window_start_hours: int
    window_end_hours: int


class Contact(BaseModel):
    phone: str
    email: str


class Defaults(BaseModel):
    webrtc: Webrtc
    hostname: str
    root_domain: str
    peer_server_port: int
    expe_upload_dir: str
    push_missing_list_to_s3: bool
    generate_missing_list_per_day: bool
    generate_subtitle_missing_list: bool
    http_verify_ssl: bool
    websocket_url: str
    internal_websocket_url: str
    send_offset_ms_to_device: bool
    show_skip_in_playout: bool
    aep_meta_ini_optional: bool
    aep_sync_timeout: int
    aep_async_render: bool
    aep_async_poll_interval: int
    check_zixi_health: bool
    check_z3_monitoring: bool
    gfx_auto_scaling: bool
    s3_ingest: bool
    new_edit: bool
    email_exception: bool
    priority_to_download: int
    sirius: bool
    missing_list_bucket: MissingListBucket
    help: Help
    extract_tc_in: ExtractTcIn
    customer_template: CustomerTemplate | None
    max_asrun_start_time_diff: int
    meta_data: str | None
    mxf_channel_layout: MxfChannelLayout
    log_upload_bucket_name: str
    log_upload_bucket_region: str
    db_cleanup: DbCleanup
    byte_range_download: bool
    send_playlist_error: bool
    send_playlist_error_to: List[SendPlaylistErrorToItem]
    playlist_alerts: PlaylistAlerts
    headend_auto_register: bool
    epub: Epub
    rule_engine: bool
    google_oauth_optional: bool
    allow_customer_google_account: bool
    admin_oscar_login_optional: bool
    generate_nplm_files: bool
    days_to_combine_in_npl: int
    config_types: List[str]
    asset_encryption: bool | None
    ses_arn: str
    playout: Playout
    categories: List
    contact: Contact


class AutomationSettings(BaseModel):
    defaults: Defaults
    development: Defaults
    test: Defaults
    production: Defaults
    staging: Defaults
